==> ezpublish-4.0.0.tgz: ezpublish/extension/ezodf/translations/ita-IT/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message>
        <source>Choose document placement</source>
        <translation>Scegli la posizione del documento</translation>
    </message>
    <message>
        <source>Upload file</source>
        <translation>Upload file</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>Esporta Oggetto</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>Importazione OpenOffice.org</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>Esportazione OpenOffice.org</translation>
    </message>
    <message>
        <source>Export eZ publish content to OpenOffice.org</source>
        <translation>Esporta i contenuti di eZ publish a OpenOffice.org</translation>
    </message>
    <message>
        <source>Here you can export any eZ publish content object to an OpenOffice.org Writer document format.</source>
        <translation>Qui puoi esportare qualsiasi oggetto eZ publish in un documento in formato OpenOffice.org (odf).</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>Il domento è stato importato</translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation>L&apos;oggeto è stato importato come: %class_name</translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation>Documento importato come</translation>
    </message>
    <message>
        <source>The images are placed in the media and can be re-used.</source>
        <translation>Le immagini sono state messe nella sezione Media e potranno essere riutilizzate.</translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation>Importa un altro documento</translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation>Importa un documento OpenOffice.org</translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation>Sostituisci documento</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation>Importa a</translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ publish from this page. You are
asked where to place the document and eZ publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation>Puoi importare domenti nel formato ODF (prodotti per esempio con OpenOffice.org) in eZ publish attraverso questa pagina.
Ti sarà chiesto dove colloare il documento ed eZ publish farà il resto.
Il documento sarà convertito nella classe appropriata durante l&apos;importazione e riceverai conferma alla fine dell&apos;importazione.
Le immagini saranno collocate nella sezione Media in modo da poterle riusare.</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>Scegli la posizione del documento</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>Scegli la collocazione per l&apos;oggetto OpenOffice.org.
    Scegli le tue collocazioni e premi il pulsante %buttonname.
    È possibile usare gli elementi preferiti e recenti per una veloce collocazione.
    Clicca sui nomi delle collocazioni per modificare l&apos;elenco da sfogliare.</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selezione</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>Formato del file destinazione non supportato</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>Conversione a pdf fallita</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Conversione Word fallita</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>Impossibile trovare il nodo o mancato permesso di lettura</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>Impossibile aprire il file %1 sul server</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>Tipo di estensione o tipo di file non ammesso.</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>Impossibile elaborare la parte XML.</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>Impossibile aprire il socket. Controllare che il demone extension/ezodf/daemon.php stia funzionando.</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>Impossibile convertire il documento.</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>Impossibile chiamare il demone. Fork non riesce a careare il processo figlio.</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>Il demone ha riportato un errore.</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>Nodo sconosciuto.</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>Accesso negato.</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>Errore durante l&apos;importazione.</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>Classe sconociuta specificata in odf.ini:</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Errore sconosciuto.</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>Tipo di file: </translation>
    </message>
    <message>
        <source>Unable to fetch node with id  </source>
        <translation>Impossibile leggere il nodo con id </translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>La directory per le immagini non può essere creata per errore di accesso negato.</translation>
    </message>
    <message>
        <source>Document is not suported.</source>
        <translation>Il documento non è supportato.</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>Impossibile importare. File non trovato. Già importato?</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>Impossibile importare il documento, il nodeID specificato non è valido.</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>Impossibile salvare il file caricato, impossibile importare.</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export OpenOffice.org</source>
        <translation>Esportazione OpenOffice.org</translation>
    </message>
    <message>
        <source>Export PDF</source>
        <translation>Esporta PDF</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>Esporta Word</translation>
    </message>
    <message>
        <source>Import OpenOffice.org</source>
        <translation>Importazione OpenOffice.org</translation>
    </message>
    <message>
        <source>Replace OpenOffice.org</source>
        <translation>Sostituisci OpenOffice.org</translation>
    </message>
</context>
</TS>

==> ezpublish-4.1.3.tgz: ezpublish/extension/ezodf/translations/ita-IT/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Upload file</source>
        <translation>Upload file</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>Esporta Oggetto</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>Importazione OpenOffice.org</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>Esportazione OpenOffice.org</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>Il domento è stato importato</translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation>L&apos;oggeto è stato importato come: %class_name</translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation>Documento importato come</translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation>Importa un altro documento</translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation>Importa un documento OpenOffice.org</translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation>Sostituisci documento</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation>Importa a</translation>
    </message>
    <message>
        <source>Export eZ Publish content to OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Here you can export any eZ Publish content object to an OpenOffice.org Writer document format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The images are placed in the media library and can be re-used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ Publish from this page. You are
asked where to place the document and eZ Publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>Scegli la posizione del documento</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>Scegli la collocazione per l&apos;oggetto OpenOffice.org.
    Scegli le tue collocazioni e premi il pulsante %buttonname.
    È possibile usare gli elementi preferiti e recenti per una veloce collocazione.
    Clicca sui nomi delle collocazioni per modificare l&apos;elenco da sfogliare.</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selezione</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>Formato del file destinazione non supportato</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>Conversione a pdf fallita</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Conversione Word fallita</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>Impossibile trovare il nodo o mancato permesso di lettura</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>Impossibile aprire il file %1 sul server</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>Tipo di estensione o tipo di file non ammesso.</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>Impossibile elaborare la parte XML.</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>Impossibile aprire il socket. Controllare che il demone extension/ezodf/daemon.php stia funzionando.</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>Impossibile convertire il documento.</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>Impossibile chiamare il demone. Fork non riesce a careare il processo figlio.</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>Il demone ha riportato un errore.</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>Nodo sconosciuto.</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>Accesso negato.</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>Errore durante l&apos;importazione.</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>Classe sconociuta specificata in odf.ini:</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Errore sconosciuto.</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>Tipo di file: </translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>La directory per le immagini non può essere creata per errore di accesso negato.</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>Impossibile importare. File non trovato. Già importato?</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>Impossibile importare il documento, il nodeID specificato non è valido.</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>Impossibile salvare il file caricato, impossibile importare.</translation>
    </message>
    <message>
        <source>Unable to fetch node with id </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export PDF</source>
        <translation>Esporta PDF</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>Esporta Word</translation>
    </message>
    <message>
        <source>OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
